==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>Reproductor MPRIS</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Selecciona Reproductor:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Añadir Reproductor</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar Reproductor</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Eliminar Reproductor</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Añadir Reproductor</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar Reproductor</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Reproductor:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Servicio:</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mprisplayer_mediaplayer/translations/mprisplayer_mediaplayer_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>Reproductor MPRIS</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Selecciona Reproductor:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Añadir Reproductor</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar Reproductor</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Eliminar Reproductor</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Añadir Reproductor</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar Reproductor</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Reproductor:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Servicio:</translation>
    </message>
</context>
</TS>
